@@ -12,16 +12,15 @@ each window individually. Stores log data to the filesystem.
 
 import time
 import subprocess
-import os
+import ctypes
 
 from sqlalchemy import *
-from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
-
 from .Base import Base
 from .TimeTracker import TimeTracker
 from .Config import Config
-from .Log import Log
+from .UserActivityTracker import UserActivityTracker
+
 
 class Latte(object):
     """ Main application class. """
@@ -33,23 +32,29 @@ class Latte(object):
         self.session = sessionmaker(bind=engine)
         Base.metadata.create_all(engine)
 
-        self.tracker = TimeTracker(config=self.config, session=self.session())
+        self.time_tracker = TimeTracker(config=self.config, session=self.session())
+        self.activity_tracker = UserActivityTracker(time_tracker=self.time_tracker, config=self.config)
 
     def run(self):
         if not has_required_dependencies():
-            print "Required dependencies were not found. Please make sure `xprop` is installed and in your PATH. Exiting..."
+            print "Required dependencies were not found. Please make sure `xprop` is installed and is in your PATH. Exiting..."
             return
+        if not has_optional_dependencies():
+            print "Optional dependencies were not found. Please make sure `libX11.so` and `libXss.so` are installed. Inactivity tracking will not work."
+
         duration = 0
         try:
             while True:
-                title = get_active_window_title()
-                self.tracker.log(title)
-                stats = self.tracker.get_window_stats(title)
-                if stats:
-                    print "%s, %s" % (title, stats.duration)
-                elif not stats:
-                    print "IGNORED"
-
+                if self.activity_tracker.is_user_inactive():
+                    print "User inactive"
+                else:
+                    title = get_active_window_title()
+                    self.time_tracker.log(title)
+                    stats = self.time_tracker.current_log
+                    if stats:
+                        print "%s, %s" % (title, stats.duration)
+                    elif not stats:
+                        print "IGNORED"
                 time.sleep(self.config.get('sleep_time'))
         except KeyboardInterrupt:
             print 'Exiting...'
@@ -57,23 +62,33 @@ class Latte(object):
     def get_session(self):
         return self.session()
 
+
 def has_required_dependencies():
-    """ Checks whether the system has required dependencies"""
+    """ Checks whether the system has required dependencies """
     try:
         subprocess.call(["xprop", "-root", "_NET_ACTIVE_WINDOW"], stdout=subprocess.PIPE)
         return True
     except OSError as e:
         return False
 
+def has_optional_dependencies():
+    """ Checks whether the system has optional dependencies """
+    try:
+        xlib = ctypes.cdll.LoadLibrary('libX11.so')
+        xss = ctypes.cdll.LoadLibrary('libXss.so')
+        return True
+    except OSError as e:
+        return False
+
 def get_active_window_title():
     """ Fetches active window title using xprop. """
     try:
         active = subprocess.Popen(["xprop", "-root", "_NET_ACTIVE_WINDOW"],
-                                stdout=subprocess.PIPE)
+                                  stdout=subprocess.PIPE)
         active_id = active.communicate()[0].strip().split()[-1]
         window = subprocess.Popen(["xprop", "-id", active_id, "WM_NAME"],
-                                stdout=subprocess.PIPE,
-                                stderr=subprocess.PIPE)
+                                  stdout=subprocess.PIPE,
+                                  stderr=subprocess.PIPE)
         result = window.communicate()[0].strip().split('"', 1)[-1][:-1]
         return unicode(result.decode('utf-8'))
     except:
